<?php

declare(strict_types=1);

namespace Drupal\easy_carousel\Render;

use Drupal\easy_carousel\CarouselInterface;
use Drupal\easy_carousel\Entity\CarouselItem;

/**
 * Provides an interface defining a carousel builder.
 */
interface CarouselRenderInterface {

  /**
   * Build the carousel render array.
   *
   * @param CarouselInterface $carousel
   *   The Carousel to render.
   * @param array $configuration
   *   The block configuration.
   *
   * @return array
   *   The renderable array.
   */
  public function render(CarouselInterface $carousel, array $configuration): array;

  /**
   * Get unique id for the block/carousel.
   *
   * Same carousel could be rendered in multiple blocks, so this function ensure
   * that the configuration exists for the carousel with the same id.
   *
   * @param CarouselInterface $carousel
   *   The carousel entity.
   * @param array $configuration
   *   The block configuration.
   *
   * @return string
   */
  public function getUniqueId(CarouselInterface $carousel, array $configuration): string;

  /**
   * Get the values of the carousel object.
   *
   * @param CarouselInterface $carousel
   *  The carousel item entity.
   *
   * @param array $configuration
   *  The block configuration.
   *
   * @return array
   *   The raw values.
   */
  public function getAllValues(CarouselInterface$carousel, array $configuration): array;
}
