<?php

namespace Drupal\easy_carousel\Render;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Traversable;

/**
 * Manages RenderMode plugins for the Easy Carousel module.
 *
 * This class extends DefaultPluginManager to discover, load, and manage
 * render mode plugins located in the `Plugin/RenderMode` directory.
 * Plugins must implement `CarouselRenderInterface` and use the `@RenderMode`
 * annotation.
 *
 * Main functionalities:
 * - Automatically discovers RenderMode plugins.
 * - Allows other modules to alter plugin definitions using
 *   `hook_easy_carousel_render_mode_info_alter()`.
 * - Utilizes caching to improve performance by storing plugin definitions.
 *
 * @see \Drupal\easy_carousel\Render\CarouselRenderInterface
 * @see \Drupal\easy_carousel\Annotation\RenderMode
 */
class RenderModeManager extends DefaultPluginManager {
  public function __construct(Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/RenderMode', $namespaces, $module_handler, 'Drupal\easy_carousel\Render\CarouselRenderInterface', 'Drupal\easy_carousel\Annotation\RenderMode');
    $this->alterInfo('easy_carousel_render_mode_info');
    $this->setCacheBackend($cache_backend, 'easy_carousel_render_mode_plugins');
  }
}
